# Generated by Django 3.2 on 2021-04-22 19:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("reports", "0002_delete_identifier"),
    ]

    operations = [
        migrations.AlterField(
            model_name="sessiondataqualityreport",
            name="unmatched_sponsor_organizations",
            field=models.JSONField(),
        ),
        migrations.AlterField(
            model_name="sessiondataqualityreport",
            name="unmatched_sponsor_people",
            field=models.JSONField(),
        ),
        migrations.AlterField(
            model_name="sessiondataqualityreport",
            name="unmatched_voters",
            field=models.JSONField(),
        ),
    ]
